@@ -6,6 +6,8 @@ from pathlib import Path
 import csv
 from urllib.parse import urlparse
 import subprocess
+import string 
+import random
 
 import ipyvuetify as v
 
@@ -113,4 +115,15 @@ def launch(command, output=None):
             if output:
                 displayIO(output, line)
     
-    return output_txt
\ No newline at end of file
+    return output_txt
+
+def random_string(string_length=3):
+    """Generates a random string of fixed length. 
+    Args:
+        string_length (int, optional): Fixed length. Defaults to 3.
+    Returns:
+        str: A random string
+    """
+    # random.seed(1001)
+    letters = string.ascii_lowercase
+    return ''.join(random.choice(letters) for i in range(string_length))
\ No newline at end of file
